@@ -61,6 +61,7 @@ import java.util.concurrent.RejectedExecutionHandler;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
@@ -178,7 +179,7 @@ public class AsyncExecutor implements ICounter {
 
             try (final InputStream inputStm = (InputStream) jobProperties.get(Properties.PROP_INPUT_STREAM)) {
                 if (StringUtils.isNotEmpty(m_jobType) && ((null != inputFile) || (null != inputStm))) {
-                    final File tempInputFile = ManagerBasics.createTempFile("oxasync", null);
+                    final File tempInputFile = DocumentConverterManager.createTempFile("oxasync", null);
 
                     if (null != tempInputFile) {
                         if (null != inputFile) {
@@ -196,7 +197,7 @@ public class AsyncExecutor implements ICounter {
                     }
                 }
             } catch (final Exception e) {
-                ManagerBasics.logExcpImpl(m_manager, e);
+                DocumentConverterManager.logExcp(e);
             }
 
             if (!isValid()) {
@@ -234,7 +235,7 @@ public class AsyncExecutor implements ICounter {
             decrement();
 
             if (isValid()) {
-                logDebug("Documentconverter started asynchronous conversion", m_jobProperties);
+                logDebug("DC started asynchronous conversion", m_jobProperties);
 
                 final HashMap<String, Object> resultProperties = new HashMap<>(8);
                 IOUtils.closeQuietly(m_documentConverter.convert(m_jobType, m_jobProperties, resultProperties));
@@ -242,7 +243,7 @@ public class AsyncExecutor implements ICounter {
                 // increment run counter by one
                 m_ranCounter.incrementAndGet();
 
-                logDebug("Documentconverter finished asynchronous conversion", m_jobProperties);
+                logDebug("DC finished asynchronous conversion", m_jobProperties);
             }
 
             clear();
@@ -295,11 +296,11 @@ public class AsyncExecutor implements ICounter {
             } else {
                 final File inputFile = (File) m_jobProperties.get(Properties.PROP_INPUT_FILE);
                 final String locale = (String) m_jobProperties.get(Properties.PROP_LOCALE);
-                final StringBuilder fileHashBuilder = ManagerBasics.getFileHashBuilder(inputFile, locale);
+                final StringBuilder fileHashBuilder = DocumentConverterManager.getFileHashBuilder(inputFile, locale);
 
                 if (null != fileHashBuilder) {
                     asyncHashBuilder.append(m_jobType).append('-').
-                        append(ManagerBasics.getFileHashBuilder(inputFile, locale).toString());
+                        append(DocumentConverterManager.getFileHashBuilder(inputFile, locale).toString());
                 } else {
                     asyncHashBuilder = null;
                 }
@@ -325,7 +326,7 @@ public class AsyncExecutor implements ICounter {
      * @param manager
      * @param maxThreadCount
      */
-    public AsyncExecutor(@NonNull IDocumentConverter converter, @NonNull ManagerBasics manager, int maxThreadCount) {
+    public AsyncExecutor(@NonNull IDocumentConverter converter, @NonNull DocumentConverterManager manager, int maxThreadCount) {
         super();
 
         if (maxThreadCount > 0) {
@@ -404,29 +405,51 @@ public class AsyncExecutor implements ICounter {
     // - public API ------------------------------------------------------------
 
     public void terminate() {
-        AsyncExecutor.AsyncRunnable curRunnable = null;
+        if (m_isRunning.compareAndSet(true, false)) {
+            final boolean trace = DocumentConverterManager.isLogTrace();
+            long traceStartTimeMillis = 0;
 
-        isTerminated = true;
+            AsyncExecutor.AsyncRunnable curRunnable = null;
 
-        while((curRunnable = (AsyncExecutor.AsyncRunnable) m_requestQueue.poll()) != null) {
-            // decrement queue count by one
-            decrement();
-            curRunnable.clear();
+            if (trace) {
+                traceStartTimeMillis = System.currentTimeMillis();
+                DocumentConverterManager.logTrace("DC AsyncExecutor starting shutdown...");
+            }
+
+            while((curRunnable = (AsyncExecutor.AsyncRunnable) m_requestQueue.poll()) != null) {
+                // decrement queue count by one
+                decrement();
+                curRunnable.clear();
+            }
+
+            if (trace) {
+                DocumentConverterManager.logTrace(new StringBuilder(256).
+                    append("DC AsyncExecutor finished shutdown: ").
+                    append(System.currentTimeMillis() - traceStartTimeMillis).append("ms").
+                    append('!').toString());
+            }
         }
     }
 
+    /**
+     * @return
+     */
+    boolean isRunning() {
+        return m_isRunning.get();
+    }
+
     /**
      * @param jobType
      * @param jobProperties
      * @param resultProperties
      */
     public void triggerExecution(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        if (!isTerminated && (null != m_requestExecutor) && (null != jobType) && (null != jobProperties) && (null != resultProperties)) {
+        if (isRunning() && (null != m_requestExecutor) && (null != jobType) && (null != jobProperties) && (null != resultProperties)) {
             final AsyncExecutor.AsyncRunnable asyncRunnable = new AsyncExecutor.AsyncRunnable(jobType, jobProperties);
 
             if (asyncRunnable.isValid()) {
                 if (needsRunning(asyncRunnable)) {
-                    logDebug("Documentconverter scheduled asynchronous job", asyncRunnable.getJobProperties());
+                    logDebug("DC scheduled asynchronous job", asyncRunnable.getJobProperties());
 
                     // increment queue count by one
                     increment();
@@ -439,8 +462,8 @@ public class AsyncExecutor implements ICounter {
                     asyncRunnable.clear();
                 }
             } else {
-                if (ManagerBasics.isLogWarnImpl(m_manager)) {
-                    ManagerBasics.logImpl(m_manager, LogType.LOGTYPE_WARN, "Documentconverter is not able to execute async. job without file input, stream input or cached hash value set => please set source input property accordingly", null);
+                if (DocumentConverterManager.isLogWarn()) {
+                    DocumentConverterManager.logWarn("DC is not able to execute async. job without file input, stream input or cached hash value set => please set source input property accordingly");
                 }
             }
         }
@@ -485,20 +508,20 @@ public class AsyncExecutor implements ICounter {
      * @param jobProperties
      */
     protected void logDebug(@NonNull final String text, @NonNull final HashMap<String, Object> jobProperties) {
-        if (ManagerBasics.isLogDebugImpl(m_manager)) {
-            ManagerBasics.logImpl(m_manager, LogType.LOGTYPE_DEBUG, text, jobProperties, getLogData());
+        if (DocumentConverterManager.isLogDebug()) {
+            DocumentConverterManager.logDebug(text, jobProperties, getLogData());
         }
     }
 
     // - Members -----------------------------------------------------------
 
     protected IDocumentConverter m_documentConverter = null;
-    protected ManagerBasics m_manager = null;
+    protected DocumentConverterManager m_manager = null;
     protected BlockingQueue<Runnable> m_requestQueue = new ArrayBlockingQueue<>(MAX_REQUEST_QEUE_SIZE);
     protected LinkedHashSet<AsyncIdentifier> m_runSet = new LinkedHashSet<>();
     protected ThreadPoolExecutor m_requestExecutor = null;
     protected ScheduledExecutorService m_timerExecutor = Executors.newScheduledThreadPool(1);
-    protected boolean isTerminated = false;
+    protected AtomicBoolean m_isRunning = new AtomicBoolean(true);
     protected AtomicLong m_ranCounter = new AtomicLong(0);
     protected AtomicLong m_omitCounter = new AtomicLong(0);
 }
