@@ -49,6 +49,8 @@
 
 package com.openexchange.documentconverter;
 
+import org.apache.commons.lang.StringUtils;
+
 /**
  * {@link JobPriority}
  *
@@ -75,4 +77,26 @@ public enum JobPriority {
     static public JobPriority highest() {
         return JobPriority.INSTANT;
     }
+
+    /**
+     * @param jobPriorityString
+     * @return
+     */
+    static public JobPriority fromString(final String jobPriorityString) {
+        final String testString = StringUtils.lowerCase(jobPriorityString);
+
+        if (null != testString) {
+            switch (testString) {
+                case ("instant"): return JobPriority.INSTANT;
+                case ("high"): return JobPriority.HIGH;
+                case ("medium"): return JobPriority.MEDIUM;
+                case ("low"): return JobPriority.LOW;
+                case ("background"):
+                default:
+                    return JobPriority.BACKGROUND;
+            }
+        }
+
+        return JobPriority.BACKGROUND;
+    }
 }
