@@ -163,6 +163,10 @@ public class Properties {
 
     static final public String PROP_IMAGE_RESOLUTION = "ImageResolution"; // Integer
 
+    static final public String PROP_USER_REQUEST = "UserRequest"; // Boolean
+
+    static final public String PROP_CLOSE_DOCUMENT = "CloseDocument"; // Boolean
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
@@ -211,6 +215,8 @@ public class Properties {
 
     static public final String OX_DOCUMENTCONVERTER_TEMPDIR_NAME = "oxdc.tmp";
 
+    static public final String OX_DOCUMENTCONVERTER_LTSDIR_NAME = "oxdc.lts";
+
     // -------------------------------------------------------------------------
 
     @SuppressWarnings("unchecked")
